#!/bin/bash

set -e

[ -n "$P" ]
[ -n "$V" ]
[ -n "$B" ]
[ -n "$MAINTAINER" ]

if ! [ -d "$OSGEO4W_REP" ]; then
        echo no repository
        exit 1
fi

tar() { /bin/tar "$@"; }
rm() { /bin/rm "$@"; }
diff() { /bin/diff "$@"; }
sed() { /bin/sed "$@"; }
cat() { /bin/cat "$@"; }

fetchenv() {
        local IFS
        IFS=
        batch=$1
        shift

        if ! [ -f "$batch" ]; then
                echo "$batch not found"
                return 1
        fi

        srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
        dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
        diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
        envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
        cmd /c set >$srcenv
        cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
        cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
        s/\\\\/\\//g;
        s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
        s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
        diff -u $srcenv $dstenv | sed -f $envdiff >$diffenv
        . $diffenv
        PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
        rm -f $srcenv $dstenv $diffenv $envdiff
}

export OSGEO4W_ROOT=/c/OSGeo4W

fetchenv $OSGEO4W_ROOT/bin/o4w_env.bat
fetchenv "/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/vcvarsall.bat" x86

export PATH="/c/Program Files (x86)/Microsoft Visual Studio 14.0/Common7/IDE:/c/Program Files/CMake/bin:$PATH:/bin"

mkdir -p build
cd build

cmake -G "NMake Makefiles" ../..

nmake dist

cd ..

mkdir -p tmp
tar -C tmp -xzf build/proj-data-$V.tar.gz

mkdir -p $OSGEO4W_REP/x86/release/proj/$P

cat <<EOF >$OSGEO4W_REP/x86/release/proj/$P/setup.hint
sdesc: "The PROJ data (nightly master)."
ldesc: "The PROJ data (nightly master)."
category: Libs Commandline_Utilities
requires: 
maintainer: $MAINTAINER
EOF

tar -cjf $OSGEO4W_REP/x86/release/proj/$P/$P-$V-$B.tar.bz2 \
	--xform s,^tmp,apps/${P%-data}/share/proj, \
	tmp/*

tar -C .. -cjf $OSGEO4W_REP/x86/release/proj/$P/$P-$V-$B-src.tar.bz2 \
	osgeo4w/package.sh

mkdir -p $OSGEO4W_REP/x86_64/release/proj/$P
cp \
	$OSGEO4W_REP/x86/release/proj/$P/$P-$V-$B.tar.bz2 \
	$OSGEO4W_REP/x86/release/proj/$P/$P-$V-$B-src.tar.bz2 \
	$OSGEO4W_REP/x86/release/proj/$P/setup.hint \
	$OSGEO4W_REP/x86_64/release/proj/$P/

rm -r build
